@@ -8,5 +8,4 @@ SHAREPOINT_USERNAME = os.environ.get('SHAREPOINT_USERNAME', 'invalid_username')
 SHAREPOINT_PASSWORD = os.environ.get('SHAREPOINT_PASSWORD', 'invalid_password')
 
 
-SHAREPOINT_LIMIT = os.environ.get('SHAREPOINT_LIMIT', 100)
-SHAREPOINT_ROWS_PER_PAGE = os.environ.get('SHAREPOINT_ROWS_PER_PAGE', 25)
+SHAREPOINT_PAGE_SIZE = int(os.environ.get('SHAREPOINT_PAGE_SIZE', 25))
